property_value_alias_bc_short_to_long = {
    "AL": "Arabic_Letter",
    "AN": "Arabic_Number",
    "B": "Paragraph_Separator",
    "BN": "Boundary_Neutral",
    "CS": "Common_Separator",
    "EN": "European_Number",
    "ES": "European_Separator",
    "ET": "European_Terminator",
    "FSI": "First_Strong_Isolate",
    "L": "Left_To_Right",
    "LRE": "Left_To_Right_Embedding",
    "LRI": "Left_To_Right_Isolate",
    "LRO": "Left_To_Right_Override",
    "NSM": "Nonspacing_Mark",
    "ON": "Other_Neutral",
    "PDF": "Pop_Directional_Format",
    "PDI": "Pop_Directional_Isolate",
    "R": "Right_To_Left",
    "RLE": "Right_To_Left_Embedding",
    "RLI": "Right_To_Left_Isolate",
    "RLO": "Right_To_Left_Override",
    "S": "Segment_Separator",
    "WS": "White_Space",
}
