property_value_alias_gc_short_to_long = {
    "C": "Other",
    "Cc": "Control",
    "Cf": "Format",
    "Cn": "Unassigned",
    "Co": "Private_Use",
    "Cs": "Surrogate",
    "L": "Letter",
    "LC": "Cased_Letter",
    "Ll": "Lowercase_Letter",
    "Lm": "Modifier_Letter",
    "Lo": "Other_Letter",
    "Lt": "Titlecase_Letter",
    "Lu": "Uppercase_Letter",
    "M": "Mark",
    "Mc": "Spacing_Mark",
    "Me": "Enclosing_Mark",
    "Mn": "Nonspacing_Mark",
    "N": "Number",
    "Nd": "Decimal_Number",
    "Nl": "Letter_Number",
    "No": "Other_Number",
    "P": "Punctuation",
    "Pc": "Connector_Punctuation",
    "Pd": "Dash_Punctuation",
    "Pe": "Close_Punctuation",
    "Pf": "Final_Punctuation",
    "Pi": "Initial_Punctuation",
    "Po": "Other_Punctuation",
    "Ps": "Open_Punctuation",
    "S": "Symbol",
    "Sc": "Currency_Symbol",
    "Sk": "Modifier_Symbol",
    "Sm": "Math_Symbol",
    "So": "Other_Symbol",
    "Z": "Separator",
    "Zl": "Line_Separator",
    "Zp": "Paragraph_Separator",
    "Zs": "Space_Separator",
}
