property_value_alias_sc_short_to_long = {
    "Adlm": "Adlam",
    "Aghb": "Caucasian_Albanian",
    "Ahom": "Ahom",
    "Arab": "Arabic",
    "Armi": "Imperial_Aramaic",
    "Armn": "Armenian",
    "Avst": "Avestan",
    "Bali": "Balinese",
    "Bamu": "Bamum",
    "Bass": "Bassa_Vah",
    "Batk": "Batak",
    "Beng": "Bengali",
    "Bhks": "Bhaiksuki",
    "Bopo": "Bopomofo",
    "Brah": "Brahmi",
    "Brai": "Braille",
    "Bugi": "Buginese",
    "Buhd": "Buhid",
    "Cakm": "Chakma",
    "Cans": "Canadian_Aboriginal",
    "Cari": "Carian",
    "Cham": "Cham",
    "Cher": "Cherokee",
    "Chrs": "Chorasmian",
    "Copt": "Coptic",
    "Cprt": "Cypriot",
    "Cyrl": "Cyrillic",
    "Deva": "Devanagari",
    "Diak": "Dives_Akuru",
    "Dogr": "Dogra",
    "Dsrt": "Deseret",
    "Dupl": "Duployan",
    "Egyp": "Egyptian_Hieroglyphs",
    "Elba": "Elbasan",
    "Elym": "Elymaic",
    "Ethi": "Ethiopic",
    "Geor": "Georgian",
    "Glag": "Glagolitic",
    "Gong": "Gunjala_Gondi",
    "Gonm": "Masaram_Gondi",
    "Goth": "Gothic",
    "Gran": "Grantha",
    "Grek": "Greek",
    "Gujr": "Gujarati",
    "Guru": "Gurmukhi",
    "Hang": "Hangul",
    "Hani": "Han",
    "Hano": "Hanunoo",
    "Hatr": "Hatran",
    "Hebr": "Hebrew",
    "Hira": "Hiragana",
    "Hluw": "Anatolian_Hieroglyphs",
    "Hmng": "Pahawh_Hmong",
    "Hmnp": "Nyiakeng_Puachue_Hmong",
    "Hrkt": "Katakana_Or_Hiragana",
    "Hung": "Old_Hungarian",
    "Ital": "Old_Italic",
    "Java": "Javanese",
    "Kali": "Kayah_Li",
    "Kana": "Katakana",
    "Khar": "Kharoshthi",
    "Khmr": "Khmer",
    "Khoj": "Khojki",
    "Kits": "Khitan_Small_Script",
    "Knda": "Kannada",
    "Kthi": "Kaithi",
    "Lana": "Tai_Tham",
    "Laoo": "Lao",
    "Latn": "Latin",
    "Lepc": "Lepcha",
    "Limb": "Limbu",
    "Lina": "Linear_A",
    "Linb": "Linear_B",
    "Lisu": "Lisu",
    "Lyci": "Lycian",
    "Lydi": "Lydian",
    "Mahj": "Mahajani",
    "Maka": "Makasar",
    "Mand": "Mandaic",
    "Mani": "Manichaean",
    "Marc": "Marchen",
    "Medf": "Medefaidrin",
    "Mend": "Mende_Kikakui",
    "Merc": "Meroitic_Cursive",
    "Mero": "Meroitic_Hieroglyphs",
    "Mlym": "Malayalam",
    "Modi": "Modi",
    "Mong": "Mongolian",
    "Mroo": "Mro",
    "Mtei": "Meetei_Mayek",
    "Mult": "Multani",
    "Mymr": "Myanmar",
    "Nand": "Nandinagari",
    "Narb": "Old_North_Arabian",
    "Nbat": "Nabataean",
    "Newa": "Newa",
    "Nkoo": "Nko",
    "Nshu": "Nushu",
    "Ogam": "Ogham",
    "Olck": "Ol_Chiki",
    "Orkh": "Old_Turkic",
    "Orya": "Oriya",
    "Osge": "Osage",
    "Osma": "Osmanya",
    "Palm": "Palmyrene",
    "Pauc": "Pau_Cin_Hau",
    "Perm": "Old_Permic",
    "Phag": "Phags_Pa",
    "Phli": "Inscriptional_Pahlavi",
    "Phlp": "Psalter_Pahlavi",
    "Phnx": "Phoenician",
    "Plrd": "Miao",
    "Prti": "Inscriptional_Parthian",
    "Rjng": "Rejang",
    "Rohg": "Hanifi_Rohingya",
    "Runr": "Runic",
    "Samr": "Samaritan",
    "Sarb": "Old_South_Arabian",
    "Saur": "Saurashtra",
    "Sgnw": "SignWriting",
    "Shaw": "Shavian",
    "Shrd": "Sharada",
    "Sidd": "Siddham",
    "Sind": "Khudawadi",
    "Sinh": "Sinhala",
    "Sogd": "Sogdian",
    "Sogo": "Old_Sogdian",
    "Sora": "Sora_Sompeng",
    "Soyo": "Soyombo",
    "Sund": "Sundanese",
    "Sylo": "Syloti_Nagri",
    "Syrc": "Syriac",
    "Tagb": "Tagbanwa",
    "Takr": "Takri",
    "Tale": "Tai_Le",
    "Talu": "New_Tai_Lue",
    "Taml": "Tamil",
    "Tang": "Tangut",
    "Tavt": "Tai_Viet",
    "Telu": "Telugu",
    "Tfng": "Tifinagh",
    "Tglg": "Tagalog",
    "Thaa": "Thaana",
    "Thai": "Thai",
    "Tibt": "Tibetan",
    "Tirh": "Tirhuta",
    "Ugar": "Ugaritic",
    "Vaii": "Vai",
    "Wara": "Warang_Citi",
    "Wcho": "Wancho",
    "Xpeo": "Old_Persian",
    "Xsux": "Cuneiform",
    "Yezi": "Yezidi",
    "Yiii": "Yi",
    "Zanb": "Zanabazar_Square",
    "Zinh": "Inherited",
    "Zyyy": "Common",
    "Zzzz": "Unknown",
}
